@@ -3,7 +3,7 @@
 
 /**
 * @file  build.h
-* @brief Build configuration for Botan 3.9.0
+* @brief Build configuration for Botan 3.10.0
 */
 
 /* NOLINTBEGIN(*-macro-usage,*-macro-to-enum) */
@@ -26,7 +26,7 @@
 /**
 * The minor version of the release
 */
-#define BOTAN_VERSION_MINOR 9
+#define BOTAN_VERSION_MINOR 10
 
 /**
 * The patch version of the release
@@ -42,7 +42,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_VERSION_DATESTAMP 20250805
+#define BOTAN_VERSION_DATESTAMP 20251106
 
 /**
  * A string set to the release type
@@ -62,7 +62,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_VERSION_VC_REVISION "git:07e1cfe0a06b224bbb37ad534736924931184246"
+#define BOTAN_VERSION_VC_REVISION "git:e27d332089247f04e89854a2e60a3af2ec4e430f"
 
 /**
  * A macro expanding to a string that is set at build time using the
@@ -74,7 +74,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_DISTRIBUTION_INFO "Gentoo 3.9.0"
+#define BOTAN_DISTRIBUTION_INFO "Gentoo 3.10.0"
 
 /**
  * @}
@@ -126,6 +126,9 @@
 #define BOTAN_HAS_ARGON2 20210407
 #define BOTAN_HAS_ARGON2_FMT 20210407
 #define BOTAN_HAS_ARIA 20170415
+#define BOTAN_HAS_ASCON_AEAD128 20250823
+#define BOTAN_HAS_ASCON_HASH256 20250816
+#define BOTAN_HAS_ASCON_XOF128 20250817
 #define BOTAN_HAS_ASN1 20201106
 #define BOTAN_HAS_AUTO_RNG 20161126
 #define BOTAN_HAS_AUTO_SEEDING_RNG 20160821
@@ -146,6 +149,7 @@
 #define BOTAN_HAS_CAST_128 20171203
 #define BOTAN_HAS_CERTSTOR_FLATFILE 20190410
 #define BOTAN_HAS_CERTSTOR_SQL 20160818
+#define BOTAN_HAS_CERTSTOR_SQLITE3 20160818
 #define BOTAN_HAS_CERTSTOR_SYSTEM 20190411
 #define BOTAN_HAS_CHACHA 20180807
 #define BOTAN_HAS_CHACHA_RNG 20170728
@@ -195,7 +199,7 @@
 #define BOTAN_HAS_EMSA_RAW 20131128
 #define BOTAN_HAS_EMSA_X931 20140118
 #define BOTAN_HAS_ENTROPY_SOURCE 20151120
-#define BOTAN_HAS_FFI 20250506
+#define BOTAN_HAS_FFI 20250829
 #define BOTAN_HAS_FILTERS 20160415
 #define BOTAN_HAS_FPE_FE1 20131128
 #define BOTAN_HAS_FRODOKEM 20230801
@@ -231,6 +235,7 @@
 #define BOTAN_HAS_KYBER_ROUND3 20240117
 #define BOTAN_HAS_LEGACY_EC_POINT 20250101
 #define BOTAN_HAS_LION 20131128
+#define BOTAN_HAS_LZMA 20160412
 #define BOTAN_HAS_MAC 20150626
 #define BOTAN_HAS_MCELIECE 20150922
 #define BOTAN_HAS_MD4 20131128
@@ -261,7 +266,6 @@
 #define BOTAN_HAS_PKCS5_PBES2 20141119
 #define BOTAN_HAS_PKCSV15_ENCRYPTION_PADDING 20250126
 #define BOTAN_HAS_PKCSV15_SIGNATURE_PADDING 20250126
-#define BOTAN_HAS_PK_PADDING 20131128
 #define BOTAN_HAS_POLY1305 20141227
 #define BOTAN_HAS_PROCESSOR_RNG 20200508
 #define BOTAN_HAS_PSK_DB 20171119
@@ -274,6 +278,7 @@
 #define BOTAN_HAS_RIPEMD_160 20131128
 #define BOTAN_HAS_ROUGHTIME 20190220
 #define BOTAN_HAS_RSA 20160730
+#define BOTAN_HAS_RSA_ENCRYPTION_PADDING 20250720
 #define BOTAN_HAS_RSA_SIGNATURE_PADDING 20250720
 #define BOTAN_HAS_SALSA20 20171114
 #define BOTAN_HAS_SCRYPT 20180902
@@ -321,6 +326,7 @@
 #define BOTAN_HAS_TLS_13_PQC 20241208
 #define BOTAN_HAS_TLS_CBC 20161008
 #define BOTAN_HAS_TLS_SESSION_MANAGER_SQL_DB 20141219
+#define BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER 20131128
 #define BOTAN_HAS_TLS_V12_PRF 20131128
 #define BOTAN_HAS_TOTP 20180816
 #define BOTAN_HAS_TRUNCATED_HASH 20230215
@@ -420,6 +426,7 @@
 #define BOTAN_HAS_SM4_GFNI 20240803
 #define BOTAN_HAS_SM4_X86 20250311
 #define BOTAN_HAS_SOCKETS 20171216
+#define BOTAN_HAS_SQLITE3 20171118
 #define BOTAN_HAS_THREAD_UTILS 20190922
 #define BOTAN_HAS_UUID 20180930
 #define BOTAN_HAS_ZFEC_SSE2 20211211
